Enum semver_parser::lexer::Token [−][src]
pub enum Token<'input> {
Eq,
Gt,
Lt,
LtEq,
GtEq,
Caret,
Tilde,
Star,
Dot,
Comma,
Hyphen,
Plus,
Or,
Whitespace(usize, usize),
Numeric(u64),
AlphaNumeric(&'input str),
}Semver tokens.
Variants
Eq=
Gt>
Lt<
LtEq<=
GtEq>=
Caret'^`
Tilde'~`
Star'*`
Dot.
Comma,
Hyphen-
Plus+
Or'||'
Whitespace(usize, usize)any number of whitespace (\t\r\n) and its span.
Numeric(u64)Numeric component, like 0 or 42.
AlphaNumeric(&'input str)Alphanumeric component, like alpha1 or 79deadbe.
Methods
impl<'input> Token<'input>[src]
impl<'input> Token<'input>pub fn is_whitespace(&self) -> bool[src]
pub fn is_whitespace(&self) -> boolCheck if the current token is a whitespace token.
pub fn is_wildcard(&self) -> bool[src]
pub fn is_wildcard(&self) -> boolCheck if the current token is a wildcard token.