Enum semver_parser::range::WildcardVersion [−][src]
pub enum WildcardVersion {
Minor,
Patch,
}Enum representing a * version part.
This is one of variants of the Op enum wich is part of Predicate enum.
All variants represent some "match-all" cases for specific numeric parts of version.
Examples
Parsing wildcard predicate and checking that its predicates are empty.
use semver_parser::range; let r = range::parse("*")?; assert!(r.predicates.is_empty());
Variants
MinorWildcard minor version 1.*.3.
PatchWildcard patch version 1.2.*.